@@ -1,5 +1,5 @@
 
-/* Generated data (by glib-mkenums) */
+
 
 #if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
 #error Only <epiphany/epiphany.h> can be included directly.
@@ -29,9 +29,9 @@ GType ephy_session_command_get_type (void);
 #define EPHY_TYPE_NEW_TAB_FLAGS ephy_new_tab_flags_get_type()
 GType ephy_new_tab_flags_get_type (void);
 
-/* --- ephy-navigation-action.h --- */
-#define EPHY_TYPE_NAVIGATION_DIRECTION ephy_navigation_direction_get_type()
-GType ephy_navigation_direction_get_type (void);
+/* --- ephy-navigation-history-action.h --- */
+#define EPHY_TYPE_NAVIGATION_HISTORY_DIRECTION ephy_navigation_history_direction_get_type()
+GType ephy_navigation_history_direction_get_type (void);
 
 /* --- pdm-dialog.h --- */
 #define EPHY_TYPE_CLEAR_ALL_DIALOG_FLAGS pdm_clear_all_dialog_flags_get_type()
@@ -40,5 +40,5 @@ G_END_DECLS
 
 #endif /* EPHY_TYPE_BUILTINS_H */
 
-/* Generated data ends here */
+
 
